@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 
-import gtk,os,re
+import gtk,os,re,getpass,sys
 from xml.dom import minidom, Node
 
 class networksettings:
@@ -96,6 +96,11 @@ case "$ADDRESS" in
 
 
 	def __init__(self):
+		if (getpass.getuser().lower() != "root" and os.name != "nt"):
+			Warningdialog = gtk.MessageDialog(None,gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,gtk.MESSAGE_WARNING,gtk.BUTTONS_OK,"You need to be root in order to run this program.")
+			Warningdialog.run()
+			Warningdialog.destroy()
+			sys.exit()
 	        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
 	        self.window.set_title("Network settings")
 	        self.window.set_border_width(4)
@@ -929,13 +934,16 @@ case "$ADDRESS" in
 
 						if (Networkset.getAttribute("IS_WIRELESS") == "1" or Networkset.getAttribute("SETTINGNAME") == "default"):
 							if (Networkset.getAttribute("SETTINGNAME") == "default"):
-								returnstr_wireless = "*,*,*,*|"+Networkset.getAttribute("SETTINGNAME")+",*,*,*)\n"
+								returnstr_wireless = "*,*,*,*|default,*,*,*)\n"
+							else:
+								returnstr_wireless = Networkset.getAttribute("SETTINGNAME") + ",*,*,*)\n"
+							
+							if (Networkset.getAttribute("IS_WIRELESS") == "0"):
 								returnstr_wireless += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
 								returnstr_wireless += "\tESSID=\"any\"\n"
 								returnstr_wireless += "\tMODE=\"Managed\"\n"
 								returnstr_wireless += "\tKEY=\"\"\n"
 							else:
-								returnstr_wireless = Networkset.getAttribute("SETTINGNAME") + ",*,*,*)\n"
 								returnstr_wireless += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
 								
 								if (Networkset.getAttribute("USE_ANY_ESSID") == "1"):
